@@ -37,5 +37,5 @@ class PTRCalibration:
         if not os.path.isdir(archive_path):
             os.mkdir(archive_path)
         out = pd.concat(self.frames)
-        out.to_csv(os.path.join(extracted_path, f"Extracted Log Files.csv"))
-        out.to_csv(os.path.join(archive_path, f"Extracted Log Files_{self.TODAY}.csv"))
\ No newline at end of file
+        out.to_csv(os.path.join(extracted_path, f"Extracted Log Files.csv"), index=False)
+        out.to_csv(os.path.join(archive_path, f"Extracted Log Files_{self.TODAY}.csv"), index=False)
\ No newline at end of file
